@@ -64,11 +64,24 @@ create_table_pages_html <- function(rs, cntnt, lpg_rows) {
       message("Page by variable not sorted.")
   }
   
+  # Deal with invisible columns
+  if (!is.null(ts$col_defs)) {
+    for (def in ts$col_defs) {
+      if (def$visible == FALSE) {
+        nnm <- paste0("..x.", def$var_c)
+        dat[[nnm]] <- dat[[def$var_c]]
+      }
+    }
+  }
+  
+  # Get control column names 
+  control_cols <- names(dat)[is.controlv(names(dat))]
+  
   # Get vector of all included column names
   # Not all columns in dataset are necessarily included
   # depends on show_cols parameter on create_table and
   # visible parameter on column definitions
-  keys <- get_table_cols(ts)
+  keys <- get_table_cols(ts, control_cols)
   # print("keys")
   # print(keys)
   
@@ -128,11 +141,15 @@ create_table_pages_html <- function(rs, cntnt, lpg_rows) {
   # print("Original Widths")
   # print(widths(dat))
   
+  # Don't merge if there is a stub with background color
+  merge_label_row <- TRUE
+  if (has_style(rs, "table_stub_background") & "stub" %in% keys)
+    merge_label_row <- FALSE
   
   # Get column widths
   widths_uom <- get_col_widths_variable(fdat, ts, labels, 
                                         rs$font, rs$font_size, rs$units, 
-                                        rs$gutter_width) 
+                                        rs$gutter_width, merge_label_row) 
   # print("Widths UOM")
   # print(widths_uom)
   
@@ -146,7 +163,7 @@ create_table_pages_html <- function(rs, cntnt, lpg_rows) {
   
   # Break columns into pages
   wraps <- get_page_wraps(rs$line_size, ts, 
-                          widths_uom, 0)  # No gutter width for RTF
+                          widths_uom, 0, control_cols)  # No gutter width for RTF
   # print("wraps")
   # print(wraps)
   
@@ -565,14 +582,18 @@ get_table_header_html <- function(rs, ts, pi, ex_brdr = FALSE) {
       tmp <- split_string_html(lbls[k], widths[k], rs$units)
       
 
+      if (ts$header_bold)
+        tstr <- paste0("<b>", encodeHTML(tmp$html), "</b>")
+      else 
+        tstr <- encodeHTML(tmp$html)
 
       if (b == "") {
         ret[1] <- paste0(ret[1], "<td class=\"thdr ", ha[k], "\">", 
-                         encodeHTML(tmp$html), "</td>\n")
+                         tstr, "</td>\n")
       } else {
         ret[1] <- paste0(ret[1], "<td class=\"thdr ", ha[k], "\" ", 
                                  "style=\"", b, "\">", 
-                         encodeHTML(tmp$html), "</td>\n")
+                         tstr, "</td>\n")
         
       }
       
@@ -887,6 +908,13 @@ get_table_body_html <- function(rs, tbl, widths, algns, talgn, tbrdrs,
   if (frb)
     strpmod <- 0
   
+  merge_label_row <- TRUE
+  if (has_style(rs, "table_stub_background") & "stub" %in% nms)
+    merge_label_row <- FALSE
+  
+  pdf(NULL)
+  par(family = get_font_family(rs$font), ps = rs$font_size)
+  
   
   # Table Body
   for(i in seq_len(nrow(t))) {
@@ -907,6 +935,7 @@ get_table_body_html <- function(rs, tbl, widths, algns, talgn, tbrdrs,
         
         sflg <- nms[j] == "stub" &  has_style(rs, "table_stub_background")
         
+        
         b <- get_cell_borders_html(i, j, nrow(t), ncol(t), brdrs, flgs[i], 
                                    exclude = exclude_top, 
                                    border_color = get_style(rs, "border_color"),
@@ -916,33 +945,59 @@ get_table_body_html <- function(rs, tbl, widths, algns, talgn, tbrdrs,
         if ( nms[j] == "stub" & flgs[i] == "L")
           lrflg <- " tlr"
         
-        # Construct html
-        if (b == "") {
-          if (i %% 2 == strpmod) {
-            ret[i] <- paste0(ret[i], "<td class=\"", ca[j], lrflg, "\">", 
-                             encodeHTML(t[i, j]), "</td>")
-          } else {
-            ret[i] <- paste0(ret[i], "<td class=\"", castr[j], lrflg, "\">", 
-                             encodeHTML(t[i, j]), "</td>")
-          }
-        } else { 
-
-          if (i %% 2 == strpmod) {
-            ret[i] <- paste0(ret[i], "<td class=\"", ca[j], lrflg, 
-                             "\" style=\"", b, "\">", 
-                             encodeHTML(t[i, j]), "</td>")
-          } else {
-            ret[i] <- paste0(ret[i], "<td class=\"", castr[j], lrflg, 
-                             "\" style=\"", b, "\">", 
-                             encodeHTML(t[i, j]), "</td>")
-          }
+        # Stripe class
+        if (i %% 2 == strpmod) {
+          scls <- ca[j]
+        } else {
+          scls <- castr[j]
         }
         
         vl <- t[i, j]
         if (all(class(vl) != "character"))
           vl <- as.character(vl)
         
-        # Count lines in cell - Doesn't work right
+        if (merge_label_row  & flgs[i] %in% c("B", "L")) {
+          if (j == 1) {
+            
+            # # Strip out line feeds for label rows
+            # vl <- gsub("\n", " ", vl, fixed = TRUE)
+            # 
+            # # Recalculate based on total width of table
+            # tmp <- split_string_html(vl, sum(wdths), rs$units)
+            # 
+            # vl <- tmp$html
+          
+            if (b == "") {
+              
+              ret[i] <- paste0(ret[i], "<td class=\"", scls, lrflg, "\"",
+                               " colspan = \"", ncol(t), "\">", 
+                               encodeHTML(vl), "</td>")
+            } else { 
+              
+              ret[i] <- paste0(ret[i], "<td class=\"", scls, lrflg, "\"",
+                               " colspan = \"", ncol(t), "\"",
+                               " style=\"", b, "\">", 
+                               encodeHTML(vl), "</td>")
+            }
+          
+          
+          }
+        } else {
+          
+          # Construct html
+          if (b == "") {
+  
+            ret[i] <- paste0(ret[i], "<td class=\"", scls, lrflg, "\">", 
+                             encodeHTML(t[i, j]), "</td>")
+          } else { 
+            
+            ret[i] <- paste0(ret[i], "<td class=\"", scls, lrflg, 
+                             "\" style=\"", b, "\">", 
+                             encodeHTML(t[i, j]), "</td>")
+          }
+        }
+        
+        # Count lines in cell
         cl <- strsplit(vl, "\n", fixed = TRUE)[[1]]
         if (length(cl) > mxrw)
           mxrw <- length(cl) 
@@ -960,6 +1015,8 @@ get_table_body_html <- function(rs, tbl, widths, algns, talgn, tbrdrs,
     
   }
   
+  dev.off()
+  
   if ("bottom" %in% get_outer_borders(brdrs))
     border_flag <- TRUE
   
