@@ -46,72 +46,93 @@ get_page_header_rtf <- function(rs) {
   
   hl <- rs$page_header_left
   hr <- rs$page_header_right
+
   conv <- rs$twip_conversion
   lh <- rs$row_height
   
+  # User controlled width of left column
+  lwdth <- rs$page_header_width
+  if (is.null(lwdth))
+    lwdth <- rs$content_size[["width"]]/2
+  
+  # Calculate right column width
+  rwdth <- rs$content_size[["width"]] - lwdth
+  
   maxh <- max(length(hl), length(hr))
   
-  if (maxh > 0) {
+  if (maxh > 0 | length(rs$header_titles) > 0) {
     
     fs <- rs$font_size * 2
     
-    c2 <- round(rs$content_size[["width"]] * conv)
-    c1 <- round(c2 / 2)
+    c1 <- round(lwdth * conv) 
+    c2 <- round(rwdth * conv) + c1
     
     ret <- paste0("{\\header \\f0\\fs", fs)
     
-    pdf(NULL)
-    par(family = get_font_family(rs$font), ps = rs$font_size)
-    
-    
-    for (i in seq(1, maxh)) {
-      ret <- paste0(ret, "\\trowd\\trgaph0\\trrh", lh, 
-                    "\\cellx", c1, "\\cellx", c2)
+    if (maxh > 0) {
+      pdf(NULL)
+      par(family = get_font_family(rs$font), ps = rs$font_size)
       
-      if (length(hl) >= i) {
+      for (i in seq(1, maxh)) {
+        ret <- paste0(ret, "\\trowd\\trgaph0\\trrh", lh, 
+                      "\\cellx", c1, "\\cellx", c2)
         
-        # Split strings if they exceed width
-        tmp <- split_string_rtf(hl[[i]], rs$content_size[["width"]]/2, rs$units)
+        if (length(hl) >= i) {
+          
+          # Split strings if they exceed width
+          tmp <- split_string_rtf(hl[[i]], lwdth, rs$units)
+          
+          ret <- paste0(ret, "\\ql ", get_page_numbers_rtf(tmp$rtf), "\\cell")
+          lcnt <- tmp$lines
+          
+        } else {
+          ret <- paste0(ret, "\\ql \\cell")
+          lcnt <- 1 
+        }
         
-        ret <- paste0(ret, "\\ql ", get_page_numbers_rtf(tmp$rtf), "\\cell")
-        lcnt <- tmp$lines
+        if (length(hr) >= i) {
+          
+          # Split strings if they exceed width
+          tmp2 <- split_string_rtf(hr[[i]], rwdth, rs$units)
+          
+          ret <- paste0(ret, "\\qr ", get_page_numbers_rtf(tmp2$rtf), "\\cell\\row\n")
+          rcnt <- tmp2$lines
+          
+        } else {
+          ret <- paste0(ret, "\\qr \\cell\\row\n")
+          rcnt <- 1
+        }
         
-      } else {
-        ret <- paste0(ret, "\\ql \\cell")
-        lcnt <- 1 
+        if (lcnt > rcnt)
+          cnt <- cnt + lcnt
+        else 
+          cnt <- cnt + rcnt
       }
       
-      if (length(hr) >= i) {
-        
-        # Split strings if they exceed width
-        tmp2 <- split_string_rtf(hr[[i]], rs$content_size[["width"]]/2, rs$units)
-        
-        ret <- paste0(ret, "\\qr ", get_page_numbers_rtf(tmp2$rtf), "\\cell\\row\n")
-        rcnt <- tmp2$lines
-        
+      dev.off()
+
+    
+      if (rs$page_header_blank_row == "below") {
+        ret <- paste0(ret, "\\par\\pard", rs$font_rtf, rs$spacing_multiplier)
+        cnt <- cnt + 1
       } else {
-        ret <- paste0(ret, "\\qr \\cell\\row\n")
-        rcnt <- 1
+        
+        ret <- paste0(ret, "\\fs1\\sl0\\par\\pard", rs$font_rtf, 
+                      rs$spacing_multiplier) 
       }
-      
-      if (lcnt > rcnt)
-        cnt <- cnt + lcnt
-      else 
-        cnt <- cnt + rcnt
     }
     
-    dev.off()
+    htitles <- ""
+    if (!is.null(rs$header_titles)) {
+    
+      tret <- get_titles_rtf(rs$header_titles, rs$content_size[["width"]], rs)
+      htitles <- paste0(tret$rtf, "\\fs1\\sl0\\par\\pard", rs$font_rtf, 
+                                              rs$spacing_multiplier) 
+      cnt <- cnt + tret$lines
     
-    if (rs$page_header_blank_row == "below") {
-      ret <- paste0(ret, "\\par\\pard", rs$font_rtf, rs$spacing_multiplier)
-      cnt <- cnt + 1
-    } else {
-      
-      ret <- paste0(ret, "\\fs1\\sl0\\par\\pard", rs$font_rtf, 
-                    rs$spacing_multiplier) 
     }
     
-    ret <- paste0(ret, "}")
+    ret <- paste0(ret, htitles, "}")
   }
   
   twps <- cnt * lh
@@ -137,7 +158,7 @@ get_page_footer_rtf <- function(rs) {
   
   maxf <- max(length(fl), length(fc), length(fr))
   
-  if (maxf > 0) {
+  if (maxf > 0 | length(rs$footer_footnotes) > 0) {
     
     fs <- rs$font_size * 2
     
@@ -145,60 +166,76 @@ get_page_footer_rtf <- function(rs) {
     c1 <- round(c3 / 3)
     c2 <- round(c1 * 2)
     
-    ret <- paste0("{\\footer \\f0\\fs", fs)
+    ret <- paste0("{\\footer \\f0\\fs", fs, "[ff]")
     
-    pdf(NULL)
-    par(family = get_font_family(rs$font), ps = rs$font_size)
+    if (maxf > 0) {
+      pdf(NULL)
+      par(family = get_font_family(rs$font), ps = rs$font_size)
+      
+      for (i in seq(1, maxf)) {
+        
+        ret <- paste0(ret, "\\trowd\\trgaph0\\cellx", c1, 
+                      "\\cellx", c2 , "\\cellx", c3)
+        
+        if (length(fl) >= i) {
+          
+          # Split strings if they exceed width
+          tmp1 <- split_string_rtf(fl[[i]], rs$content_size[["width"]]/3, rs$units)
+          
+          ret <- paste0(ret, "\\ql ", get_page_numbers_rtf(tmp1$rtf), "\\cell")
+          lcnt <- tmp1$lines
+        } else {
+          ret <- paste0(ret, "\\ql \\cell")
+          lcnt <- 1
+        }
+        
+        if (length(fc) >= i) {
+          
+          # Split strings if they exceed width
+          tmp2 <- split_string_rtf(fc[[i]], rs$content_size[["width"]]/3, rs$units)
+          
+          ret <- paste0(ret, "\\qc ", get_page_numbers_rtf(tmp2$rtf), "\\cell")
+          ccnt <- tmp2$lines
+        } else {
+          ret <- paste0(ret, "\\qc \\cell")
+          ccnt <- 1
+        }
+        
+        if (length(fr) >= i) {
+          
+          tmp3 <- split_string_rtf(fr[[i]], rs$content_size[["width"]]/3, rs$units)
+          
+          ret <- paste0(ret, "\\qr ", get_page_numbers_rtf(tmp3$rtf), "\\cell\\row\n")
+          rcnt <- tmp3$lines
+        } else {
+          ret <- paste0(ret, "\\qr \\cell\\row\n")
+          rcnt <- 1
+        }
+        
+        cnt <- cnt + max(lcnt, ccnt, rcnt)
+        
+      }
+      dev.off()
+    }
     
-    for (i in seq(1, maxf)) {
+    
+    ffootnotes <- ""
+    if (!is.null(rs$footer_footnotes)) {
       
-      ret <- paste0(ret, "\\trowd\\trgaph0\\cellx", c1, 
-                    "\\cellx", c2 , "\\cellx", c3)
-      
-      if (length(fl) >= i) {
-        
-        # Split strings if they exceed width
-        tmp1 <- split_string_rtf(fl[[i]], rs$content_size[["width"]]/3, rs$units)
-        
-        ret <- paste0(ret, "\\ql ", get_page_numbers_rtf(tmp1$rtf), "\\cell")
-        lcnt <- tmp1$lines
-      } else {
-        ret <- paste0(ret, "\\ql \\cell")
-        lcnt <- 1
-      }
-      
-      if (length(fc) >= i) {
-        
-        # Split strings if they exceed width
-        tmp2 <- split_string_rtf(fc[[i]], rs$content_size[["width"]]/3, rs$units)
-        
-        ret <- paste0(ret, "\\qc ", get_page_numbers_rtf(tmp2$rtf), "\\cell")
-        ccnt <- tmp2$lines
-      } else {
-        ret <- paste0(ret, "\\qc \\cell")
-        ccnt <- 1
-      }
-      
-      if (length(fr) >= i) {
-        
-        tmp3 <- split_string_rtf(fr[[i]], rs$content_size[["width"]]/3, rs$units)
-        
-        ret <- paste0(ret, "\\qr ", get_page_numbers_rtf(tmp3$rtf), "\\cell\\row\n")
-        rcnt <- tmp3$lines
-      } else {
-        ret <- paste0(ret, "\\qr \\cell\\row\n")
-        rcnt <- 1
-      }
-      
-      cnt <- cnt + max(lcnt, ccnt, rcnt)
+      tret <- get_footnotes_rtf(rs$footer_footnotes, rs$content_size[["width"]], rs)
+      ffootnotes <- paste0(tret$rtf, "\\fs1\\sl0\\par\\pard", rs$font_rtf, 
+                        rs$spacing_multiplier) 
+      cnt <- cnt + tret$lines
       
     }
-    dev.off()
+    
+    ret <- sub("[ff]", ffootnotes, ret, fixed = TRUE)
     
     ret <- paste0(ret, "\\fs1\\sl0\\par\\pard", 
                   rs$font_rtf, rs$spacing_multiplier, "}")
   }
   
+
   res <- list(rtf = paste0(ret, collapse = ""),
               lines = cnt, 
               twips = cnt * lh)
@@ -229,17 +266,219 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
     
     for (ttls in ttllst) {
       
+      cols <- ttls$columns
+      
       
       if (ttls$width == "page")
-        width <- rs$content_size[["width"]]
-      else if (ttls$width == "content")
-        width <- content_width
+        width <- rs$content_size[["width"]] 
+      else if (ttls$width == "content") 
+        width <- content_width 
       else if (is.numeric(ttls$width))
-        width <- ttls$width
+        width <- ttls$width 
         
       w <- round(width * conv)
       
+      cwidth <- width / cols
+      cw <- round(w / cols)
+      
 
+      if (ttls$align == "center")
+        algn <- "\\qc"
+      else if (ttls$align == "right")
+        algn <- "\\qr"
+      else 
+        algn <- "\\ql"
+      
+      border_flag <- FALSE
+      alcnt <- 0
+      blcnt <- 0
+      
+      # Open device context
+      pdf(NULL)
+      par(family = get_font_family(rs$font), ps = rs$font_size)
+      
+      
+      al <- ""
+      # Get blank row above
+      if (any(ttls$blank_row %in% c("above", "both"))) {
+        
+        alcnt <- 1
+        
+        tb <- get_cell_borders(1, 1, length(ttls$titles) + alcnt, 1, ttls$borders)
+        
+        al <- paste0("\\trowd\\trgaph0", ta, tb, "\\cellx", w, 
+                     algn, "\\cell\\row\n")
+        cnt <- cnt + 1 
+        
+      }
+      
+      bl <- ""
+      # Get blank row below
+      if (any(ttls$blank_row %in% c("below", "both"))) {
+        blcnt <- 1
+        
+        tb <- get_cell_borders(length(ttls$titles) + alcnt + blcnt, 1, 
+                               length(ttls$titles) + alcnt + blcnt, 
+                               1, ttls$borders)
+        
+        sm <- get_spacing_multiplier(rs$font_size)
+        
+        bl <- paste0("\\trowd\\trgaph0", ta, tb, "\\cellx", w, 
+                     algn, sm, "\\cell\\row\n")
+        cnt <- cnt + 1
+      }
+      
+      # Append blank row above
+      if (al != "")
+        ret <- append(ret, al)
+      
+      fz <- ""
+      fs <- ""
+      # Get font size
+      if (!is.null(ttls$font_size)) {
+        
+        fz <- paste0("\\fs", ttls$font_size * 2, 
+                     get_spacing_multiplier(ttls$font_size)) 
+        fs <- paste0("\\fs", rs$font_size * 2)
+      }
+      
+      # Reset column width accumulation
+      cwa <- 0
+      
+      # Calculate total number of rows in this block
+      rws <- ceiling(length(ttls$titles) / cols) + alcnt + blcnt
+
+      i <- 1
+      while (i <= length(ttls$titles)) {    
+        
+        mxlns <- 0
+        
+        # Calculate current row
+        rw <- ceiling(i / cols)
+
+        # Start row
+        ret <- append(ret, paste0("\\trowd\\trgaph0", ta))
+        
+        for (j in seq_len(cols)) {
+          
+          # Get border specs for this cell
+          b <- get_cell_borders(rw + alcnt, j, 
+                                rws, 
+                                cols, ttls$borders)
+          
+          # Not all cells have titles
+          if (i > length(ttls$titles))
+            vl <- ""
+          else 
+            vl <- ttls$titles[[i]]
+          
+          # Deal with column alignments
+          if (cols == 1) {
+            calgn <- algn 
+          } else if (cols == 2) {
+           if (j == 1)
+             calgn <- "\\ql"
+           else 
+             calgn <- "\\qr"
+          } else if (cols == 3) {
+           if (j == 1)
+             calgn <- "\\ql"
+           else if (j == 2)
+             calgn <- "\\qc"
+           else if (j == 3) 
+             calgn <- "\\qr"
+          }
+          
+          if (j == 1) 
+            cwa <- 0
+        
+          # RTF cell widths are absolute ending points
+          cwa <- cwa + cw
+          
+          # Split title strings if they exceed width
+          tmp <- split_string_rtf(vl, cwidth, rs$units)
+          
+          # Track max lines for counting
+          if (tmp$lines > mxlns)
+            mxlns <- tmp$lines
+
+          # Add bold if needed
+          tb <- tmp$rtf
+          if (ttls$bold)
+            tb <- paste0("\\b ", tmp$rtf, "\\b0")
+          
+          # Contruct cell from constituent parts
+          ret <- append(ret, paste0(b, "\\cellx", cwa, 
+                                    calgn, fz, " ", tb, fs, "\\cell"))
+          
+          i <- i + 1
+          
+        }
+        
+        # End row
+        ret <- append(ret, "\\row\n")
+
+        # Track lines
+        cnt <- cnt + mxlns
+      }
+      
+      # Append blank row below
+      if (bl != "")
+        ret <- append(ret, bl)
+      
+      if (any(ttls$borders %in% c("outside", "all", "bottom")))
+        border_flag <- TRUE
+      
+      dev.off()
+    
+    }
+    
+  }
+  
+  res <- list(rtf = paste0(ret, collapse = ""), 
+              lines = cnt, 
+              twips = cnt * lh,
+              border_flag = border_flag)
+  
+  return(res)
+}
+
+
+
+#' @import grDevices
+#' @noRd
+get_titles_rtf_back <- function(ttllst, content_width, rs, talgn = "center") {
+  
+  ret <- c()
+  cnt <- 0
+  twps <- 0
+  
+  conv <- rs$twip_conversion
+  lh <- rs$row_height
+  border_flag <- FALSE
+  
+  
+  ta <- "\\trql"
+  if (talgn == "right")
+    ta <- "\\trqr"
+  else if (talgn %in% c("center", "centre"))
+    ta <- "\\trqc"
+  
+  if (length(ttllst) > 0) {
+    
+    for (ttls in ttllst) {
+      
+      
+      if (ttls$width == "page")
+        width <- rs$content_size[["width"]]
+      else if (ttls$width == "content")
+        width <- content_width
+      else if (is.numeric(ttls$width))
+        width <- ttls$width
+      
+      w <- round(width * conv)
+      
+      
       if (ttls$align == "center")
         algn <- "\\qc"
       else if (ttls$align == "right")
@@ -257,10 +496,10 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
       
       for (i in seq_along(ttls$titles)) {
         
-
+        
         
         al <- ""
-
+        
         if (i == 1) {
           if (any(ttls$blank_row %in% c("above", "both"))) {
             
@@ -269,9 +508,9 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
             tb <- get_cell_borders(i, 1, length(ttls$titles) + alcnt, 1, ttls$borders)
             
             al <- paste0("\\trowd\\trgaph0", ta, tb, "\\cellx", w, 
-                                      algn, "\\cell\\row\n")
+                         algn, "\\cell\\row\n")
             cnt <- cnt + 1 
-
+            
           }
         }
         
@@ -323,11 +562,11 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
                                   algn, fz, " ", tb, fs, "\\cell\\row\n"))
         if (bl != "")
           ret <- append(ret, bl)
-
+        
         cnt <- cnt + tmp$lines
       }
       dev.off()
-    
+      
     }
     
   }
@@ -747,8 +986,8 @@ get_cell_borders <- function(row, col, nrow, ncol, brdrs, flag = "", exclude = N
   if (!is.na(flag)) {
     if (flag %in% c("L", "B")) {
       
-      if (col != ncol)
-        r <- ""
+      if (col == 1 & any(brdrs %in% c("outside", "right", "all")))
+        r <- "\\clbrdrr\\brdrs"
       
       if (col != 1)
         l <- ""
