@@ -112,6 +112,8 @@
 #' border specifications only apply to RTF, HTML, PDF, and DOCX reports.  
 #' The 'body' border 
 #' specification means put borders around only the body of the table.
+#' @param header_bold Whether or not the column headers on the tables should
+#' be bolded.  Valid values are TRUE and FALSE.  The default is FALSE.
 #' @family table
 #' @seealso \code{\link{create_report}} to create a report, 
 #' \code{\link{create_plot}} to create a plot,
@@ -185,7 +187,7 @@ create_table <- function(x, show_cols = "all", use_attributes = "all",
                          width = NULL, 
                          first_row_blank=FALSE,
                          n_format = upcase_parens, headerless = FALSE,
-                         borders = "none") {
+                         borders = "none", header_bold = FALSE) {
   if (is.null(x)) {
     stop("Data parameter 'x' missing or invalid.") 
     
@@ -234,6 +236,7 @@ create_table <- function(x, show_cols = "all", use_attributes = "all",
   ret$width <- width
   ret$page_var <- NULL
   ret$borders <- borders
+  ret$header_bold <- header_bold
   if (any(use_attributes == "all"))
     ret$use_attributes <- c("label", "width", "justify", "format")
   else if (all(use_attributes == "none"))
@@ -491,8 +494,15 @@ define <- function(x, vars, label = NULL, format = NULL,
   # This make subsequent processing much easier
   for (nm in vars_c) {
     
+    if (has_glue()) {
+      lbl <- gluev(label) 
+    } else {
+      
+      lbl <- label
+    }
     
-   def <- define_c(nm, label = label, format = format, 
+    
+   def <- define_c(nm, label = lbl, format = format, 
                    align=align, label_align=label_align, width=width,
                    visible=visible, n = n, blank_after=blank_after,
                    dedupe=dedupe, id_var = id_var, page_wrap = page_wrap,
@@ -1072,10 +1082,15 @@ spanning_header <- function(x, from, to, label = "",
   endpos <- match(t, nms)
   spn <- nms[startpos:endpos]
   
+  if (has_glue()) {
+    sh$label <- gluev(label)
+  } else {
+    sh$label <- label
+  }
+  
   sh$span_cols <- spn
   sh$from = f
   sh$to = t
-  sh$label = label
   sh$label_align = label_align
   sh$level = level
   sh$n = n
@@ -1297,8 +1312,11 @@ stub <- function(x, vars, label = "", label_align = NULL,
     }
   }
   
-  
-  def$label <- label
+  if (has_glue()) {
+    def$label <- gluev(label)
+  } else {
+    def$label <- label
+  }
   def$label_align <- label_align
   def$align <- align
   def$vars <- vars_c
